# NOT RUN {
# Use raw example data
data <- taskdata1
# Create a network diagram chart using the raw data
network_diagram(data)
res <- critical_path(data)
# Create a second network diagram using the processed data
network_diagram(res)
# }
Run the code above in your browser using DataLab